/*

Ringo Robot
Ringo_NavigateCommands
Simple program to allow Adrian to come up with program for Ringo to navigate a maze.
The "calibration" is to fine tune the standard run-time for the motors ( in forward/reverse) to cover standard distance on the maze
grid.

The four funtions are:
F(x), which will move ahead X squares
R(x), which will move in reverse X squares
L(), makes a left turn
R(), makes a right turn
----- erase following after testing code ------
***************************************************
// Movement functions
// ***************************************************
//
//To use movement functions, user code must first call "NavigationBegin()", which initializes
//the navigation sensors (though some of them call it automatically).
//Most of these call "CalibrateNavigationSensors()" in beginning.
//NavigationBegin() calls CalibrateNavigationSensors() for you.
//Navigation will be innacurate if robot is moving when calling NavigationBegin() or
//CalibrateNavigationSensors().
//
//Since gravity is a much larger acceleration than it will usually accelerate in
//the XY plane, even slight tipping forwards and backwards will have a huge effect
//if the average tilt while running is significantly different than when the
//nagigation sensors were calibrated.
//
//If 0 entered for EdgeFunction, the move functions will not look for edges.
//If something like B will be called when an edge is detected.
//

extern int HeadingWithShortestDistance(int Heading);
//Figures out which of 2 directions (left or right) to turn (in order to get
//from current direction to Heading.
//Ex: if currently 0 degrees, then HeadingWithShortestDistance(300) will
//return -60 degrees.

extern void MoveXYWithOptions(int X, int Y, int Speed, int MaxExpectedRunTime, int MaxExpectedSkidTime, void (*EdgeFunction)(char), char Wiggle);
//  Goes towards destination {X,Y}.
//    However, this function calculates with both x and y acceleration so is not
//    affected by the Wiggle parameter.
//  ex: ZeroNavigation();MoveXYWithOptions(0,200,150,3000,500,0,50);
//    Since navigation zeroed, it is at coordinates {0,0} and facing 0 degrees (Pi/2 radians) along y-axis.
//    It will wiggle back and forth but still should stop after its y-coordinate reaches
//    approximately 200mm.
//  In general, this function draws a finish line that is perpendicular to
//    the route from the initial to final {x,y} position. It then continuously
//    resets the "heading" parameter so that it is facing towards the final position
//    and stops when the original finish line is crossed.
//

void MoveWithOptions(int Heading, int Distance, int Speed, int MaxExpectedRunTime, int MaxExpectedSkidTime, void (*EdgeFunction)(char), char Wiggle);
//  Translates Heading & Distance to X,Y and calls MoveXYWithOptions()

extern void RotateSimple(int TurnDegrees, int left, int right, int MaxExpectedTurnTime, int MaxExpectedSkidTime);
//  ex: RotateSimple(GetDegrees()+90, 150, 0, 1000, 250);//approximate rotation
//    Set left motor to 150 and right motor to 0. Stop both motors when the
//    heading we expect to be at after skidding to a halt is 90 degrees to the
//    right of its initial heading.
//  Note: this uses GetDegreesToStop() which looks at how fast it is currently
//    rotating (GetDegreesPerSecond()) and estimates how much further it will
//    go if motors are turned off right now.
//
extern char RotateAccurate(int Heading, int MaxExpectedTurnTime);
//  ex: RotateAccurate(45,1000);
//    exact rotation (45 degrees to right if ZeroNavigation() just called) with timeout of 1000ms
//


*/

#include "RingoHardware.h"


void setup() {
  HardwareBegin();        //initialize Ringo's brain to work with his circuitry
  PlayStartChirp();       //Play startup chirp and blink eyes
  delay(5000);            // wait 5 sec before starting Navigation
  NavigationBegin();
  //SwitchMotorsToSerial(); //Call "SwitchMotorsToSerial()" before using Serial.print functions as motors & serial share a line
  RestartTimer();
}

void loop() {

  // add your own code here
//simple motor testing:
//MoveWithOptions(heading,distance,speed,maxruntime,maxSkidtime,edgefunction, wiggle)
//MoveXYWithOptions(x,y,speed,maxruntime,maxSkidtime,edgefunction, wiggle)
MoveWithOptions(0, 100, 150, 3000, 1000, 0,0); // this should produce pretty straight movement--go forward 150mm

delay(1000);
//RotateSimple(degrees,left,right,turnTime,SkidTime)
//RotateSimple(90,0,150,2000,800); // turn 90
//MoveWithOptions(0, -100, -150, 3000, 1000, 0,0);
//delay (1000);

}









